@@ -5,4 +5,6 @@ from .flare import *
 from .deploy import *
 from .local import *
 from .vi import *
+from .assets import *
+from .vue import *
 from .setup import *
